@@ -114,6 +114,7 @@ nt_thread_tp nt_thread_alloc(
 		free(threadp);
 		return NULL;
 	}
+	threadp->num_res = num_res;
 	threadp->reslistp = NULL;
 
 	linkp = boardp->threadlistp;
@@ -126,6 +127,9 @@ nt_thread_tp nt_thread_alloc(
 	}
 	if(linkp == NULL)
 		boardp->threadlistp = ptr;
+
+	threadp->seq_no = nt_link_num(boardp->threadlistp);
+
 	return threadp;
 }
 
