@@ -254,15 +254,9 @@ BOOL parse_board(nt_board_tp boardp, const wchar_t *linep)
 		num_res = 0;
 	}
 	threadp = nt_thread_alloc(boardp, cptr1, buf, num_res);
-	if(!threadp)
-		return FALSE;
-	/* threadp = malloc(sizeof(nt_thread_t));
 	if(!threadp)
 		return FALSE;
 
-	threadp->name = nt_w_trim(cptr1);
-	threadp->address = nt_w_trim(buf);
-	threadp->num_res = num_res; */
 	return TRUE;
 }
 
