@@ -18,10 +18,12 @@
 char LOG_PATH[1024];
 char USR_PATH[1024];
 char USR_COOKIE_PATH[1024];
+char USR_LOG_DB_PATH[1024];
 char EDITOR_CMD[1024]; 
 int FORCE_REFRESH = 0; 
+int THREAD_SORT_TYPE = NT_THREAD_SORT_BY_READ; 
 static char *app_name = "ntch";
-static char *version_name = "1.0.1.2";
+static char *version_name = "1.0.1.3";
 static char *def_editor_cmd = "vi";
 
 char *MARU_ID;
@@ -56,6 +58,7 @@ int set_option(int argc, char* argv[])
 	}
 	sprintf(USR_PATH, "%s/.ntch", pw->pw_dir);
 	sprintf(USR_COOKIE_PATH, "%s/cookie", USR_PATH);
+	sprintf(USR_LOG_DB_PATH, "%s/usr_log.sqlite3", USR_PATH);
 
 	sprintf(buf, "%s/.ntchrc", pw->pw_dir);
 	if(!read_resource(buf)){
@@ -113,6 +116,7 @@ extern BOOL read_resource(const char *path)
 {
 	FILE *fp;
 	char *cptr, *key, *val;
+	char *sort_type;
 	char buf[128];
 
 	fp = fopen(path, "r");
@@ -137,6 +141,22 @@ extern BOOL read_resource(const char *path)
 			MARU_PW = nt_trim(val);
 			continue;
 		}
+		key = strstr(buf, "sort");
+		if(key){
+			val = cptr+1;
+			sort_type = nt_trim(val);
+			if(!sort_type)
+				break;
+			if(0 == strcmp(sort_type, "number")){
+				THREAD_SORT_TYPE = NT_THREAD_SORT_BY_NUMBER;
+			}else if(0 == strcmp(sort_type, "read")){
+				THREAD_SORT_TYPE = NT_THREAD_SORT_BY_READ;
+			}else if(0 == strcmp(sort_type, "unread")){
+				THREAD_SORT_TYPE = NT_THREAD_SORT_BY_UNREAD;
+			}
+			free(sort_type);
+			continue;
+		}
 	}
 	fclose(fp);
 	return TRUE;
