@@ -1,7 +1,9 @@
 #ifndef _2CH_H_
 #define _2CH_H_
 
-#include "../_2ch/model_2ch.h"
+#include "net/nt_cookie.h"
+#include "_2ch/model_2ch.h"
+#include "_2ch/maru_2ch.h"
 
 extern char *URL_2CH_BOARDMENU;
 
@@ -12,5 +14,8 @@ extern BOOL nt_2ch_model_init();
 extern BOOL nt_init_board_menu();
 extern BOOL nt_read_board(nt_2ch_model_tp modelp);
 extern BOOL nt_read_thread(nt_2ch_model_tp modelp);
+extern BOOL nt_write_msg(nt_2ch_model_tp modelp, 
+			nt_write_data_tp writep, nt_cookie_tp cookiep, 
+			nt_maru_2ch_tp marup);
 
 #endif /* _2CH_H_ */
