@@ -4,11 +4,18 @@
 extern char LOG_PATH[];
 extern char USR_PATH[];
 extern char USR_COOKIE_PATH[];
+extern char USR_LOG_DB_PATH[];
+
 extern int FORCE_REFRESH;
-extern char EDITOR_CMD[];
+extern int THREAD_SORT_TYPE; 
+extern char EDITOR_CMD[]; 
 extern char *MARU_ID;
 extern char *MARU_PW;
 
+#define NT_THREAD_SORT_BY_NUMBER 1
+#define NT_THREAD_SORT_BY_UNREAD 2
+#define NT_THREAD_SORT_BY_READ 3
+
 #define NT_KEY_NONE (-1)
 #define NT_KEY_UP 'k'
 #define NT_KEY_DOWN 'j'
@@ -31,6 +38,16 @@ extern char *MARU_PW;
 
 #define NT_COMMAND1_WRITE_MSG_1 "write"
 #define NT_COMMAND1_WRITE_MSG_2 "w"
+#define NT_COMMAND1_JMP_NEW_1 "new"
+#define NT_COMMAND1_JMP_NEW_2 "n"
+#define NT_COMMAND1_SORT_1 "sort"
+#define NT_COMMAND1_SORT_2 "s"
+#define NT_COMMNAD1_SORT_NUMBER_1 "number"
+#define NT_COMMNAD1_SORT_NUMBER_2 "n"
+#define NT_COMMNAD1_SORT_READ_1 "read" 
+#define NT_COMMNAD1_SORT_READ_2 "r" 
+#define NT_COMMNAD1_SORT_UNREAD_1 "unread"
+#define NT_COMMNAD1_SORT_UNREAD_2 "u"
 
 extern int set_option(int argc, char* argv[]);
 
