@@ -4,5 +4,7 @@
 #define NT_ERR_MSG_COUDLNOT_READ_BOARD (L"板情報が読み込めませんでした")
 #define NT_ERR_MSG_WRITE_MSG_LENGTH (L"メッセージが指定されていません")
 #define NT_ERR_MSG_WRITE_MSG_ABORTED (L"中止しました")
+#define NT_ERR_MSG_REFRESH_THREAD_FAILED (L"スレッドの更新に失敗しました")
+#define NT_ERR_MSG_SEARCH_NOT_FOUND (L"文字列が見つかりませんでした")
 
 #endif /*_ERROR_H_*/
