@@ -13,7 +13,7 @@
 
 #define HTTP_RESPONCE_HEADER_BUFFER_LEN  256
 
-#define USER_AGENT "Monazilla/1.00 (monaweb/1.00) NeetchanLinux"
+#define USER_AGENT "Monazilla/1.00 (monaweb/1.00) ntch for GUN/Linux"
 
 #define CONTENT_TYPE_ZIP 1
 #define CONTENT_TYPE_TEXT 2 
