@@ -5,6 +5,8 @@
 #define NT_TEXT_DEF_MAIL "sage" 
 
 #define NT_INFO_WRITE_MSG_SUCCESS (L"メッセージを書き込みました")
+#define NT_INFO_REFRESH_THREAD_SUCCESS (L"スレッドを更新しました")
+#define NT_INFO_REFRESH_BOARD_SUCCESS (L"板を更新しました")
 
 
 #endif /* _NT_STRING_H */
