@@ -14,10 +14,11 @@
 extern int disp_board_menu(nt_window_tp wp, 
 		nt_2ch_model_tp modelp);
 extern int disp_threadlist(nt_window_tp wp, 
-		nt_2ch_model_tp modelp);
+		nt_2ch_model_tp modelp, void *usr_db_handle);
 extern int disp_reslist(nt_window_tp wp, 
-		nt_2ch_model_tp modelp);
+		nt_2ch_model_tp modelp, void *usr_db_handle);
 extern void free_board_menu_ctx(void *ptr);
+extern void init_threadlist_ctx(void *ptr);
 extern void free_threadlist_ctx(void *ptr);
 extern void free_reslist_ctx(void *ptr);
 extern BOOL disp_editor(nt_write_data_tp writep);
