@@ -8,8 +8,8 @@
 #define FALSE 0
 
 typedef int BOOL;
-typedef void (*nt_memfree_tp)(void* ptr);
-typedef BOOL (*nt_compare_tp)(void *lhs, void *rhs);
+typedef void (*nt_memfree_fn)(void* ptr);
+typedef int (*nt_compare_fn)(void *lhs, void *rhs);
 
 typedef struct tag_nt_link_t *nt_link_tp;
 typedef struct tag_nt_link_t{
@@ -31,18 +31,23 @@ extern void* nt_stack_cursor_next();
 extern void* nt_stack_add_last(nt_stack_tp stackp, void* data);
 
 extern nt_stack_tp nt_stack_alloc();
-extern void nt_stack_free(nt_stack_tp ptr, nt_memfree_tp free_func);
+extern void nt_stack_free(nt_stack_tp ptr, nt_memfree_fn free_func);
 
 extern nt_link_tp nt_link_add_data(nt_link_tp link, void *data);
+extern nt_link_tp nt_link_insert_before(nt_link_tp top_linkp,
+			nt_link_tp dest, nt_link_tp src);
 extern nt_link_tp nt_link_remove(nt_link_tp src, nt_link_tp target);
+extern nt_link_tp nt_link_remove2(nt_link_tp src, nt_link_tp target);
 extern nt_link_tp nt_link_remove_by_data(nt_link_tp link, void *data);
 extern void* nt_link_get(nt_link_tp link);
 extern nt_link_tp nt_link_find(nt_link_tp link, void *data, 
-			nt_compare_tp comp_func);
+			nt_compare_fn comp_func);
+extern void nt_link_sort(nt_link_tp *linkp, nt_compare_fn comp_func);
 extern nt_link_tp nt_link_next(nt_link_tp link);
 extern int nt_link_num(nt_link_tp linkp);
 extern void* nt_link_get_by_index(nt_link_tp linkp, int index);
-extern void nt_all_link_free(nt_link_tp ptr, nt_memfree_tp free_func);
+extern void nt_all_link_free(nt_link_tp ptr, nt_memfree_fn free_func);
+extern nt_link_tp nt_link_copy(nt_link_tp src_linkp);
 
 typedef struct tag_nt_key_value_t *nt_key_value_tp;
 typedef struct tag_nt_key_value_t{
