@@ -8,7 +8,10 @@ extern wchar_t *nt_w_trim_quotes(const wchar_t *source);
 extern char *nt_trim2(const char *source, char *buf, size_t buf_len);
 #define nt_trim(a) nt_trim2((a), NULL,0)
 
+extern wchar_t* nt_w_str_clone(const wchar_t *cptr);
 extern char* nt_str_clone(const char *cptr);
 extern char* nt_substr(const char *cptr, int start, int end);
+extern BOOL nt_strtok(const char *str, char delim, 
+		const char** start, const char **end);
 
 #endif /* _TEXT_H_ */
