@@ -17,6 +17,7 @@
 #include "net/nt_socket.h"
 #include "net/nt_cookie.h"
 #include "utils/file.h"
+#include "utils/nt_usr_db.h"
 #include "_2ch/_2ch.h"
 #include "_2ch/maru_2ch.h"
 #include "ui/disp.h"
@@ -26,7 +27,7 @@
 #define S_SIZE 	(1024)
 
 static int draw_title(WINDOW *wp, wchar_t *title, attr_t attr);
-static BOOL DoLoop(WINDOW *scrp);
+static BOOL DoLoop(WINDOW *scrp, void *db_handle);
 static void print_error(WINDOW *wp, wchar_t *msg);
 
 
@@ -34,6 +35,7 @@ int main(int argc, char *argv[])
 {
 	int result = 1;
 	WINDOW *scrp;
+	void *usr_db_handle;
 
 	if(0 != set_option(argc, argv)){
 		return 1;
@@ -44,6 +46,13 @@ int main(int argc, char *argv[])
 
 	setlocale(LC_ALL, "ja_JP.UTF-8");
 
+	usr_db_handle = nt_usr_db_init(USR_LOG_DB_PATH);
+	if(!usr_db_handle){
+		fputs("Couldn't initialize usr database.\n", stderr);
+		printf("Exit.");
+		return 1;
+	}
+
 	scrp = initscr();
 	if(!scrp){
 		fputs("Couldn't initialize Curses libraly.\n", stderr);
@@ -64,7 +73,7 @@ int main(int argc, char *argv[])
 	cbreak();
 	noecho();
 
-	if(DoLoop(scrp))
+	if(DoLoop(scrp, usr_db_handle))
 		result = 0;
 
 	echo();
@@ -75,12 +84,16 @@ ERROR_TRAP:
 
 
 	nt_2ch_model_free(app_2ch_modelp);
+
 	endwin();
+
+	nt_usr_db_finish(usr_db_handle);
+
 	return (result);
 }
 
 
-static BOOL DoLoop(WINDOW *scrp)
+static BOOL DoLoop(WINDOW *scrp, void *db_handle)
 {
 	int ch, state, num;
 	int disp_state, nresult;
@@ -112,7 +125,7 @@ static BOOL DoLoop(WINDOW *scrp)
 	if(!rwinp)
 		return FALSE;
 
-
+	keypad(stdscr, true);
 	while(1){
 		if(FORCE_REFRESH)
 			wclear(scrp);
@@ -150,7 +163,7 @@ static BOOL DoLoop(WINDOW *scrp)
 			draw_title(scrp, title, WA_REVERSE);
 			if(!nt_disp_win_move(scrp, twinp, LINES-1, COLS, 1, 0))
 				goto END_WHILE;
-			state = disp_threadlist(twinp, app_2ch_modelp);
+			state = disp_threadlist(twinp, app_2ch_modelp, db_handle);
 			if(DISP_STATE_ERROR == state){
 				goto END_WHILE;
 			}else {
@@ -176,6 +189,9 @@ static BOOL DoLoop(WINDOW *scrp)
 						ch = NT_KEY_NONE;
 						continue;
 					}
+					if(twinp->data){
+						init_threadlist_ctx(twinp->data);
+					}
 					if(rwinp->data){
 						free_reslist_ctx(rwinp->data);
 						rwinp->data = NULL;
@@ -196,7 +212,7 @@ static BOOL DoLoop(WINDOW *scrp)
 						LINES - num, COLS, num, 0))
 				goto END_WHILE;
 			rwinp->key = ch;
-			state = disp_reslist(rwinp, app_2ch_modelp);
+			state = disp_reslist(rwinp, app_2ch_modelp, db_handle);
 			if(DISP_STATE_ERROR == state){
 				goto END_WHILE;
 			}else if(state == DISP_STATE_REFRESH){
@@ -281,18 +297,25 @@ static BOOL DoLoop(WINDOW *scrp)
 		ch = getch();
 		switch(ch){
 		case NT_KEY_UP:
+		case KEY_UP:
 		case NT_KEY_DOWN:
+		case KEY_DOWN:
 		case NT_KEY_LEFT:
 		case NT_KEY_RIGHT:
+		case KEY_RIGHT:
 		case NT_KEY_PAGEUP:
+		case KEY_PPAGE:
 		case NT_KEY_PAGEDOWN:
+		case KEY_NPAGE:
 		case NT_KEY_SELECT:
 		case NT_KEY_ADD:
 		case NT_KEY_DEL:
 		case NT_KEY_BOTTOM:
+		case KEY_END:
 		case NT_KEY_REFRESH:
 			break;
 		case NT_KEY_CLOSE:
+		case KEY_LEFT:
 			wclear(scrp);
 			break;
 		case NT_KEY_COMMAND1:
