@@ -130,16 +130,14 @@ void nt_unload_cookie(nt_cookie_tp cookiep)
 
 }
 
-static BOOL cmp_link_func(void *lhs, void *rhs)
+static int cmp_link_func(void *lhs, void *rhs)
 {
 	nt_key_value_tp l, r;
 
 	l = (nt_key_value_tp)lhs;
 	r = (nt_key_value_tp)rhs;
 
-	if(0 == strcmp(l->key, r->key))
-		return TRUE;
-	return FALSE;
+	return strcmp(l->key, r->key);
 }
 
 static void kvp_free_func(void *ptr)
