@@ -46,8 +46,6 @@ int nt_socket_connect(nt_socket_tp socketp, char* data, int data_len)
 	int sockfd;
 	int len;
 	int result;
-	//int nread, nwrite;
-	//char buf[1024];
 
 	sockfd = socket(AF_INET, SOCK_STREAM, 0);
 	if(sockfd == -1)
@@ -65,24 +63,5 @@ int nt_socket_connect(nt_socket_tp socketp, char* data, int data_len)
 		close(sockfd);
 		return -1;
 	}
-	/*do{
-		nread = read(sockfd, buf, sizeof(buf));
-		switch(nread){
-		case -1:
-			close(sockfd);
-			return -1;
-		case 0:
-			break;
-		default:
-			nwrite = write(writefd, buf, nread);
-			if(nwrite == -1){
-				close(sockfd);
-				return -1;
-			}
-			break;
-		}
-	}while(nread > 0);	
-
-	close(sockfd);*/
 	return sockfd;
 }
