@@ -77,10 +77,12 @@ int disp_board_menu(nt_window_tp wp, nt_2ch_model_tp modelp)
 	}
 	switch(wp->key){
 	case NT_KEY_UP:
+	case KEY_UP:
 		decrement_cursor(ctxp);
 		adjust_scroll_pos(wp, ctxp);
 		break;
 	case NT_KEY_DOWN: 
+	case KEY_DOWN: 
 		increment_cursor(ctxp);
 		adjust_scroll_pos(wp, ctxp);
 		break;
@@ -91,12 +93,15 @@ int disp_board_menu(nt_window_tp wp, nt_2ch_model_tp modelp)
 		move_cursor_right_colmn(wp, ctxp);
 		break;
 	case NT_KEY_PAGEUP:
+	case KEY_PPAGE:
 		page_up(wp, ctxp);
 		break;
 	case NT_KEY_PAGEDOWN:
+	case KEY_NPAGE:
 		page_down(wp, ctxp);
 		break;
 	case NT_KEY_SELECT: 
+	case KEY_RIGHT:
 		selected = TRUE;
 		break;
 	}
