@@ -9,12 +9,17 @@
 
 #include	"env.h"
 #include	"utils/nt_std_t.h"
+#include	"utils/nt_usr_db.h"
 #include	"utils/text.h"
 #include	"_2ch/_2ch.h"
 #include	"_2ch/model_2ch.h"
 #include	"ui/disp.h"
 #include	"ui/disp_string.h"
 
+#define NT_CMD_NONE -1
+#define NT_CMD_WRITE 1
+#define NT_CMD_JMP_NEW 2
+
 typedef struct tag_ctx_reslist_t *ctx_reslist_tp;
 typedef struct tag_ctx_reslist_t
 {
@@ -23,6 +28,7 @@ typedef struct tag_ctx_reslist_t
 	int cur_res_offset;
 	int max_cur_res;
 	int max_cur_offset;
+	int prev_read_cnt;
 	nt_stack_tp	selected_num_stackp;
 
 	regex_t regex;
@@ -33,16 +39,18 @@ typedef struct tag_ctx_reslist_t
 } ctx_reslist_t;
 
 
-static ctx_reslist_tp init_context(nt_2ch_model_tp modelp);
+static ctx_reslist_tp init_context(nt_2ch_model_tp modelp, 
+			void *usr_db_handle);
 static void int_ptr_free(void *ptr);
-static BOOL parse_cmd1(const char *param, int *statep);
+static int parse_cmd1(const char *param, int *statep);
 static BOOL search_line_asc(regex_t *regexp, nt_link_tp reslistp, 
 			int *sel_res_no, int *sel_res_line, int column);
 static BOOL search_line_desc(regex_t *regexp, ctx_reslist_tp ctxp,
 			nt_link_tp reslistp, 
 			int *sel_res_no, int *sel_res_line, int column);
 
-int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp)
+int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp,
+	void *usr_db_handle)
 {
 	ctx_reslist_tp ctxp;
 	nt_res_tp resp;
@@ -63,10 +71,12 @@ int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp)
 	BOOL adjust;
 	BOOL set_value;
 	int line_num;
+	int  cmd;
+	attr_t new_res_attr;
 
 	ctxp = (ctx_reslist_tp)wp->data;
 	if(!ctxp){
-		ctxp = init_context(modelp);
+		ctxp = init_context(modelp, usr_db_handle);
 		if(!ctxp)
 			return DISP_STATE_ERROR;
 		wp->data = ctxp;
@@ -141,8 +151,10 @@ int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp)
 	case NT_KEY_REFRESH:
 		return DISP_STATE_REFRESH; 
 	case NT_KEY_CLOSE:
+	case KEY_LEFT:
 		return DISP_STATE_THREADTITLE; 
 	case NT_KEY_BOTTOM:
+	case KEY_END:
 		if(ctxp->cur_res == ctxp->res_num - 1)
 			break;
 		if(!threadp->reslistp)
@@ -298,31 +310,46 @@ int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp)
 		break;
 	case NT_KEY_COMMAND1:
 		assert(wp->cmd_param);
-		if(parse_cmd1(wp->cmd_param, &state)){
+		cmd = parse_cmd1(wp->cmd_param, &state);
+		switch(cmd){
+		case NT_CMD_WRITE:
 			return state;
-		}
-		num = atoi(wp->cmd_param);
-		if(0 == num)
+		case NT_CMD_JMP_NEW:
+			if(ctxp->prev_read_cnt <= 0)
+				ctxp->cur_res = 0;
+			else if(ctxp->prev_read_cnt >= ctxp->res_num){
+				ctxp->cur_res = ctxp->res_num - 1;
+			}else{
+				ctxp->cur_res = ctxp->prev_read_cnt;
+			}
+			ctxp->cur_res_offset = 0;
 			break;
-		num--;
-		if(ctxp->cur_res == num)
+		default:
+			num = atoi(wp->cmd_param);
+			if(0 == num)
+				break;
+			num--;
+			if(ctxp->cur_res == num)
+				break;
+			if(num >= ctxp->res_num)
+				break;
+			nptr = malloc(sizeof(int));
+			*nptr = ctxp->cur_res;
+			ctxp->cur_res = num;
+			ctxp->cur_res_offset = 0;
+			if(!threadp->reslistp){
+				free(nptr);
+				break;
+			}
+			clistp = threadp->reslistp;
+			for(i = 0; i < num; i++)
+				clistp = clistp->next;
+			nt_stack_push(ctxp->selected_num_stackp, nptr);
 			break;
-		if(num >= ctxp->res_num)
-			break;
-		nptr = malloc(sizeof(int));
-		*nptr = ctxp->cur_res;
-		ctxp->cur_res = num;
-		ctxp->cur_res_offset = 0;
-		if(!threadp->reslistp){
-			free(nptr);
-			break;
-		}
-		clistp = threadp->reslistp;
-		for(i = 0; i < num; i++)
-			clistp = clistp->next;
-		nt_stack_push(ctxp->selected_num_stackp, nptr);
+		}/* end switch */
 		break;
 	case NT_KEY_UP:
+	case KEY_UP:
 		ctxp->cur_res_offset--;
 		if(0 <= ctxp->cur_res_offset){
 			break;
@@ -370,6 +397,7 @@ int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp)
 		ctxp->cur_res_offset = num;
 		break;
 	case NT_KEY_DOWN:
+	case KEY_DOWN:
 		ctxp->cur_res_offset++;
 		clistp = threadp->reslistp;
 		for(i = 0; i < ctxp->res_num; i++){
@@ -411,6 +439,7 @@ int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp)
 		}
 		break;
 	case NT_KEY_PAGEUP:
+	case KEY_PPAGE:
 		ctxp->cur_res_offset -= wp->lines;
 		if(ctxp->cur_res_offset >= 0){
 			break;
@@ -468,6 +497,7 @@ int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp)
 		}
 		break;
 	case NT_KEY_PAGEDOWN:
+	case KEY_NPAGE:
 		clistp = threadp->reslistp;
 		if(0 > ctxp->cur_res)
 			ctxp->cur_res = 0;
@@ -548,12 +578,19 @@ int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp)
 		len = wcslen(buf);
 		num = nt_get_wc_count_within_colmns(buf, wp->cols);
 
+		if(ctxp->res_num == ctxp->prev_read_cnt)
+			new_res_attr = 0;
+		else if(i+1 > ctxp->prev_read_cnt)
+			new_res_attr = WA_BOLD;
+		else
+			new_res_attr = 0;
+
 		if(num < len){
 			if(!nt_w_str_move(buf, sizeof(buf), num, 1))
 				break;
 			if(res_offset >= ctxp->cur_res_offset){
 				wmove(wp->wp, rows, 0);
-				nt_add_wstr(wp->wp, buf, 0);
+				nt_add_wstr(wp->wp, buf, new_res_attr);
 				rows++;
 			}else{
 				res_offset++;
@@ -563,8 +600,9 @@ int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp)
 			if(res_offset >= ctxp->cur_res_offset){
 				wmove(wp->wp, rows, 0);
 				nt_add_wnch(wp->wp, L' ', WA_UNDERLINE, 5);
-				nt_add_wnstr(wp->wp, buf + num + 1, WA_UNDERLINE,
-				wp->cols - 5);
+				nt_add_wnstr(wp->wp, buf + num + 1, 
+							new_res_attr | WA_UNDERLINE,
+							wp->cols - 5);
 				rows++;
 			}else{
 				res_offset++;
@@ -572,7 +610,8 @@ int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp)
 		}else{
 			if(res_offset >= ctxp->cur_res_offset){
 				wmove(wp->wp, rows, 0);
-				nt_add_wstr(wp->wp, buf, WA_UNDERLINE);
+				nt_add_wstr(wp->wp, buf, 
+							new_res_attr | WA_UNDERLINE);
 				rows++;
 			}else{
 				res_offset++;
@@ -626,31 +665,39 @@ END_FOR:
 	return DISP_STATE_RESLIST; 
 }
 
-static BOOL parse_cmd1(const char *param, int *statep)
+static int parse_cmd1(const char *param, int *statep)
 {
 	assert(param);
 
 	if(0 == strcmp(NT_COMMAND1_WRITE_MSG_1, param) ||
 		0 == strcmp(NT_COMMAND1_WRITE_MSG_2, param)){
 		*statep = DISP_STATE_EDITOR;
-		return TRUE;
-
+		return NT_CMD_WRITE;
+	}else if(0 == strcmp(NT_COMMAND1_JMP_NEW_1, param) ||
+		0 == strcmp(NT_COMMAND1_JMP_NEW_2, param)){
+		return NT_CMD_JMP_NEW;
 	}
-	return FALSE;
+	return NT_CMD_NONE;
 }
 
 
 
-static ctx_reslist_tp init_context(nt_2ch_model_tp modelp)
+static ctx_reslist_tp init_context(nt_2ch_model_tp modelp,
+	void *usr_db_handle)
 {
 	ctx_reslist_tp ctxp;
+	nt_board_tp boardp;
 	nt_thread_tp threadp;
+
+	boardp = modelp->selected_boardp;
+	threadp = modelp->selected_threadp;
+	assert(boardp && threadp);
+
 	ctxp = (ctx_reslist_tp)calloc(1,sizeof(ctx_reslist_t));
 
 	if(!ctxp)
 		return NULL;
 
-	threadp = modelp->selected_threadp;
 	if(threadp->reslistp)
 		ctxp->res_num = nt_link_num(threadp->reslistp);
 	ctxp->cur_res = 0;
@@ -662,6 +709,16 @@ static ctx_reslist_tp init_context(nt_2ch_model_tp modelp)
 	ctxp->sel_res_no = -1;
 	ctxp->sel_res_line = -1;
 
+	ctxp->prev_read_cnt = 
+		nt_usr_db_update_read_count(usr_db_handle,
+				boardp->name, threadp->file_name,
+				ctxp->res_num);
+	if(ctxp->prev_read_cnt < 0)
+		ctxp->prev_read_cnt = 0;
+	if(ctxp->prev_read_cnt > 0){
+		ctxp->cur_res = ctxp->prev_read_cnt;
+	}
+
 	return ctxp;
 }
 
