@@ -3,6 +3,49 @@
 #include <assert.h>
 #include "utils/nt_std_t.h"
 
+
+nt_link_tp nt_link_insert_before(nt_link_tp top_linkp,
+		nt_link_tp dest, nt_link_tp src)
+{
+	if(top_linkp == dest){
+		src->next = top_linkp;
+		src->prev = top_linkp->prev;
+		src->prev->next = src;
+		src->next->prev = src;
+		return src;
+	}
+
+	src->next = dest;
+	src->prev = dest->prev;
+	src->prev->next = src;
+	src->next->prev = src;
+
+	return top_linkp;
+}
+
+void nt_link_sort(nt_link_tp *top_linkp, nt_compare_fn comp_func)
+{
+	nt_link_tp cur_linkp, next_linkp, work_linkp;
+
+	cur_linkp = *top_linkp;
+	do{
+		next_linkp = cur_linkp->next;
+		work_linkp = *top_linkp;
+
+		while(work_linkp != cur_linkp){
+			if(0 < (comp_func)(cur_linkp->data, work_linkp->data)){
+				*top_linkp = nt_link_remove2(*top_linkp, cur_linkp);
+				*top_linkp = nt_link_insert_before(
+						*top_linkp, work_linkp, cur_linkp);
+				break;
+			}
+			work_linkp = work_linkp->next;
+		}
+		cur_linkp = next_linkp;
+	}while(cur_linkp != *top_linkp);
+
+}
+
 int nt_link_num(nt_link_tp linkp){
 	nt_link_tp curp;
 	int num = 1;
@@ -66,6 +109,25 @@ nt_link_tp nt_link_remove(nt_link_tp src, nt_link_tp target)
 	return target;
 }
 
+nt_link_tp nt_link_remove2(nt_link_tp top_linkp, nt_link_tp target)
+{
+	nt_link_tp new_top_linkp, prev, next;
+
+	if(top_linkp == target){
+		if(top_linkp == top_linkp->next)
+			return NULL;
+		new_top_linkp = top_linkp->next;
+	}else{
+		new_top_linkp = top_linkp;
+	}
+	prev = target->prev;
+	next = target->next;
+	prev->next = next;
+	next->prev = prev;
+
+	return new_top_linkp;
+}
+
 nt_link_tp nt_link_remove_by_data(nt_link_tp link, void *data)
 {
 	nt_link_tp ptr = link;
@@ -87,11 +149,11 @@ void* nt_link_get(nt_link_tp link)
 }
 
 nt_link_tp nt_link_find(nt_link_tp link, void *data, 
-					nt_compare_tp comp_func)
+					nt_compare_fn comp_func)
 {
 	nt_link_tp ptr = link;
 	do{
-		if((comp_func)(ptr->data, data)){
+		if(0 == (comp_func)(ptr->data, data)){
 			return ptr;
 		}
 		ptr = ptr->next;
@@ -106,7 +168,28 @@ nt_link_tp nt_link_next(nt_link_tp link)
 	return link->next;
 }
 
-void nt_all_link_free(nt_link_tp ptr, nt_memfree_tp free_func)
+nt_link_tp nt_link_copy(nt_link_tp src_linkp)
+{
+	nt_link_tp srcp, resultp, workp;
+	assert(src_linkp);
+	
+	srcp = src_linkp;
+	resultp = NULL;
+	do{
+		workp = nt_link_add_data(resultp, srcp->data);
+		if(!workp){
+			if(resultp)
+				nt_all_link_free(resultp, NULL);
+			return NULL;
+		}
+		if(!resultp)
+			resultp = workp;
+		srcp = srcp->next;
+	}while(srcp != src_linkp);
+	return resultp;
+}
+
+void nt_all_link_free(nt_link_tp ptr, nt_memfree_fn free_func)
 {
 	nt_link_tp linkp;
 	nt_link_tp tmp_linkp;
@@ -267,7 +350,7 @@ nt_stack_tp nt_stack_alloc()
 }
 
 
-void nt_stack_free(nt_stack_tp ptr, nt_memfree_tp free_func)
+void nt_stack_free(nt_stack_tp ptr, nt_memfree_fn free_func)
 {
 	assert(ptr);
 
