@@ -253,6 +253,16 @@ char *nt_trim2(const char *source, char *buf, size_t buf_len)
 	return cptr;
 }
 
+wchar_t* nt_w_str_clone(const wchar_t* src)
+{
+	wchar_t *cptr;
+	cptr = malloc(sizeof(wchar_t) * (wcslen(src)+1));
+	if(!cptr)
+		return NULL;
+	wcscpy(cptr, src);
+	return cptr;
+}
+
 char* nt_str_clone(const char* src)
 {
 	char *cptr;
@@ -286,4 +296,30 @@ char* nt_substr(const char* src, int start, int end)
 	return cptr;
 }
 
+BOOL nt_strtok(const char *str, char delim,
+        const char** start, const char **end)
+{
+	int i, len, state;
 
+	assert(str);
+
+	len = strlen(str);
+	*start = str;
+	*end = str + len;
+
+	state = 0;
+	for(i = 0; i < len; i++){
+		if(str[i] == delim){
+			if(state == 0){
+				*start = str + i + 1;
+			}else if(state == 1){
+				*end = str + i + 1;
+				return TRUE;
+			}
+		}else{
+			if(state == 0)
+				state = 1;
+		}
+	}
+	return TRUE;
+}
